@@ -2,7 +2,7 @@ package CPANPLUS::Backend;
 
 use strict;
 
-use CPANPLUS::inc;
+
 use CPANPLUS::Error;
 use CPANPLUS::Configure;
 use CPANPLUS::Internals;
@@ -65,11 +65,11 @@ This information might be useful somehow to spawned processes.
 
 =head1 METHODS
 
-=head2 new( [CONFIG_OBJ | config => { ... }] )
+=head2 new( [CONFIGURE_OBJ] )
 
 This method returns a new C<CPANPLUS::Backend> object.
 This also initialises the config corresponding to this object.
-You have three choices in this:
+You have two choices in this:
 
 =over 4
 
@@ -77,11 +77,6 @@ You have three choices in this:
 
 This will be used verbatim.
 
-=item Provide a few options like config => { ... }
-
-These will override your existing config, but use your default
-config for options you didn't specify.
-
 =item No arguments
 
 Your default config will be loaded and used.
@@ -100,7 +95,7 @@ sub new {
     if( $_[0] && IS_CONFOBJ->( conf => $_[0] ) ) {
         $conf = shift;
     } else {
-        $conf = CPANPLUS::Configure->new( @_ ) or return;
+        $conf = CPANPLUS::Configure->new() or return;
     }
 
     my $self = $class->SUPER::_init( _conf => $conf );
@@ -181,6 +176,17 @@ configure object.
 
 sub configure_object { return shift->_conf() };
 
+=head2 $su = $cb->selfupdate_object;
+
+Returns a copy of the C<CPANPLUS::Selfupdate> object.
+
+See the L<CPANPLUS::Selfupdate> manpage for the operations
+you can perform on the selfupdate object.
+
+=cut
+
+sub selfupdate_object { return shift->_selfupdate() };
+
 =pod
 
 =head2 search( type => TYPE, allow => AREF, [data => AREF, verbose => BOOL] )
@@ -429,6 +435,8 @@ sub parse_module {
 
     ### check only for allowed characters in a module name
     unless( $mod =~ /[^\w:]/ ) {
+
+        ### perhaps we can find it in the module tree?
         my $maybe = $self->module_tree($mod);
         return $maybe if IS_MODOBJ->( module => $maybe );
     }
@@ -455,6 +463,27 @@ sub parse_module {
         
         return $modobj;      
     }
+    
+    ### perhaps we can find it's a third party module?
+    {   my $modobj = CPANPLUS::Module::Fake->new(
+                        module  => $mod,
+                        version => 0,
+                        package => $dist,
+                        path    => File::Spec::Unix->catdir(
+                                        $conf->_get_mirror('base'),
+                                        UNKNOWN_DL_LOCATION ),
+                        author  => CPANPLUS::Module::Author::Fake->new
+                    );
+        if( $modobj->is_third_party ) {
+            my $info = $modobj->third_party_information;
+            
+            $modobj->author->author( $info->{author}     );
+            $modobj->author->email(  $info->{author_url} );
+            $modobj->description(    $info->{url} );
+
+            return $modobj;
+        }
+    }
 
     unless( $dist ) {
         error( loc("%1 is not a proper distribution name!", $mod) );
