@@ -10,6 +10,8 @@ use Config;
 
 use CPANPLUS::Error;
 
+use CPANPLUS::Selfupdate;
+
 use CPANPLUS::Internals::Source;
 use CPANPLUS::Internals::Extract;
 use CPANPLUS::Internals::Fetch;
@@ -38,7 +40,7 @@ use vars qw[@ISA $VERSION];
             CPANPLUS::Internals::Report
         ];
 
-$VERSION = "0.075_01";
+$VERSION = "0.77_02";
 
 =pod
 
@@ -86,7 +88,7 @@ is reset to this after each install.
 
 ### autogenerate accessors ###
 for my $key ( qw[_conf _id _lib _perl5lib _modules _hosts _methods _status
-                 _callbacks]
+                 _callbacks _selfupdate]
 ) {
     no strict 'refs';
     *{__PACKAGE__."::$key"} = sub {
@@ -182,6 +184,9 @@ Returns the object on success, or dies on failure.
             );
         }
 
+        ### create a selfupdate object
+        $args->_selfupdate( CPANPLUS::Selfupdate->new( $args ) );
+
         ### initalize it as an empty hashref ###
         $args->_status->pending_prereqs( {} );
 
