@@ -1,6 +1,6 @@
 package CPANPLUS::Module::Author::Fake;
 
-use CPANPLUS::inc;
+
 use CPANPLUS::Module::Author;
 use CPANPLUS::Internals;
 use CPANPLUS::Error;
@@ -61,7 +61,7 @@ sub new {
     my $obj = CPANPLUS::Module::Author->new( %$args ) or return;
 
     unless( $obj->_id ) {
-        cp_error(loc("No '%1' specified -- No CPANPLUS object associated!",'_id'));
+        error(loc("No '%1' specified -- No CPANPLUS object associated!",'_id'));
         return;
     } 
 
